CustomEvent class

Constructors

CustomEvent(String type, String appId, Map payload, int? requestId, {String? errorType})
CustomEvent.fromJson(Map json)

Properties

appId ↔ String
getter/setter pair
errorType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payload ↔ Map
getter/setter pair
requestId ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited