PaymentEvent class

Constructors

PaymentEvent(String appId, String transactionToken, String orderPaymentId, String miniappOrderId, double amount, String currency, String status, String hostappOrderId, {Map? extraParams})
PaymentEvent.fromJson(Map json)

Properties

amount ↔ double
getter/setter pair
appId ↔ String
getter/setter pair
currency ↔ String
getter/setter pair
extraParams ↔ Map?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostappOrderId ↔ String
getter/setter pair
miniappOrderId ↔ String
getter/setter pair
orderPaymentId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String
getter/setter pair
transactionToken ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited